<?php

namespace Btravel\Flight\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Flight\Models\Flight;

class FlightPolicy
{

    /**
     * Determine if the given user can view the flight.
     *
     * @param UserPolicy $user
     * @param Flight $flight
     *
     * @return bool
     */
    public function view(UserPolicy $user, Flight $flight)
    {
        if ($user->canDo('flight.flight.view') && $user->isAdmin()) {
            return true;
        }

        return $flight->user_id == user_id() && $flight->user_type == user_type();
    }

    /**
     * Determine if the given user can create a flight.
     *
     * @param UserPolicy $user
     * @param Flight $flight
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('flight.flight.create');
    }

    /**
     * Determine if the given user can update the given flight.
     *
     * @param UserPolicy $user
     * @param Flight $flight
     *
     * @return bool
     */
    public function update(UserPolicy $user, Flight $flight)
    {
        if ($user->canDo('flight.flight.edit') && $user->isAdmin()) {
            return true;
        }

        return $flight->user_id == user_id() && $flight->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given flight.
     *
     * @param UserPolicy $user
     * @param Flight $flight
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Flight $flight)
    {
        return $flight->user_id == user_id() && $flight->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given flight.
     *
     * @param UserPolicy $user
     * @param Flight $flight
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Flight $flight)
    {
        if ($user->canDo('flight.flight.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given flight.
     *
     * @param UserPolicy $user
     * @param Flight $flight
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Flight $flight)
    {
        if ($user->canDo('flight.flight.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
